@@ -88,6 +88,8 @@ class ElasticCursor(object):
         """Add extra info to response."""
         if 'facets' in self.hits:
             response['_facets'] = self.hits['facets']
+        if 'aggregations' in self.hits:
+            response['_aggregations'] = self.hits['aggregations']
 
 
 def set_filters(query, *args):
@@ -226,6 +228,9 @@ class Elastic(DataLayer):
         if 'facets' in source_config:
             query['facets'] = source_config['facets']
 
+        if 'aggregations' in source_config:
+            query['aggs'] = source_config['aggregations']
+
         args = self._es_args(resource)
         hits = self.es.search(body=query, **args)
         return self._parse_hits(hits, resource)
